import React, { useState, useEffect } from 'react'
import Taro, { useDidShow, useRouter } from '@tarojs/taro'
import { useSelector } from 'react-redux'
import { View } from '@tarojs/components'
import Overlay from '@/components/Overlay'
import Loading from '@/components/Loading'
import AuthAvatar from '@/components/Auth/AuthAvatar'
import AuthPhone from '@/components/Auth/AuthPhone'
import Spin from '@/components/Spin/Spin2'
import useAuth from './useAuth'
import { routes } from '../routes'

import './style.scss'

export default (ChildComponent) => (props) => {
  const consultant = useSelector(s => s.system.consultant)
  const { spinning, userInfo } = useSelector(s => s.user)
  const { person, ...extInfo } = userInfo || {}
  const router = useRouter()
  const [loading, setLoading] = useState(false)
  const [authPhone, authAvatar] = useAuth(person)

  
  // 主要用于埋点
  useEffect(() => {
    const page = routes.filter((r) => (router.path.indexOf(r.page) > -1))[0]
    Taro.setStorage({ key: 'page', data: page })
  }, [router.path])

  useEffect(() => {
    setLoading(!person || !person.personId)
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [person])

  useDidShow(() => {
    console.log('componentDidShow')
  })

  return (
    <>
      <Overlay visible={loading} style={{background: '#fff'}}>
        <Loading />
      </Overlay>
      <Overlay visible={authPhone} aligin='bottom'>
        <View className='auth-wrapper'>
          <AuthPhone />
        </View>
      </Overlay>
      <Overlay visible={!authPhone && authAvatar} aligin='bottom'>
        <View className='auth-wrapper'>
          <AuthAvatar />
        </View>
      </Overlay>
      <Spin size={32} spinning={spinning} />
      {
        person && person.personId
        ? <ChildComponent
            person={person}
            router={router}
            consultant={consultant}
            {...props}
            {...extInfo}
        />
        : null
      }
    </>
  )
}
